==> brmo-stufbg204-1.6.3p1-sources.jar: nl/egem/stuf/sector/bg/_0204/NATTabel.java <==

package nl.egem.stuf.sector.bg._0204;

import java.math.BigInteger;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.stuf0204.DatumMetIndicatorKerngegeven;
import nl.egem.stuf.stuf0204.ExtraElementen;
import nl.egem.stuf.stuf0204.NoValue;
import nl.egem.stuf.stuf0204.Verwerkingssoort;


/**
 * tabel entiteit nationaliteit
 * 
 * <p>Java class for NAT-tabel complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NAT-tabel">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="code" minOccurs="0">
 *           &lt;complexType>
 *             &lt;simpleContent>
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>Nationaliteitscode">
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
 *               &lt;/extension>
 *             &lt;/simpleContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="omschrijving" minOccurs="0">
 *           &lt;complexType>
 *             &lt;simpleContent>
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>NationaliteitOmschrijving">
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
 *               &lt;/extension>
 *             &lt;/simpleContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *         &lt;element name="datumVerkrijging" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicatorKerngegeven" minOccurs="0"/>
 *         &lt;element name="datumVerlies" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicatorKerngegeven" minOccurs="0"/>
 *         &lt;element name="extraElementen" type="{http://www.egem.nl/StUF/StUF0204}ExtraElementen" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}tabel"/>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NAT-tabel", propOrder = {
    "code",
    "omschrijving",
    "datumVerkrijging",
    "datumVerlies",
    "extraElementen"
})
public class NATTabel {

    @XmlElementRef(name = "code", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<NATTabel.Code> code;
    @XmlElementRef(name = "omschrijving", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<NATTabel.Omschrijving> omschrijving;
    @XmlElementRef(name = "datumVerkrijging", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<DatumMetIndicatorKerngegeven> datumVerkrijging;
    @XmlElementRef(name = "datumVerlies", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<DatumMetIndicatorKerngegeven> datumVerlies;
    protected ExtraElementen extraElementen;
    @XmlAttribute(name = "soortEntiteit", required = true)
    protected String soortEntiteit;
    @XmlAttribute(name = "verwerkingssoort", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Verwerkingssoort verwerkingssoort;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;

    /**
     * Gets the value of the code property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link NATTabel.Code }{@code >}
     *     
     */
    public JAXBElement<NATTabel.Code> getCode() {
        return code;
    }

    /**
     * Sets the value of the code property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link NATTabel.Code }{@code >}
     *     
     */
    public void setCode(JAXBElement<NATTabel.Code> value) {
        this.code = value;
    }

    /**
     * Gets the value of the omschrijving property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link NATTabel.Omschrijving }{@code >}
     *     
     */
    public JAXBElement<NATTabel.Omschrijving> getOmschrijving() {
        return omschrijving;
    }

    /**
     * Sets the value of the omschrijving property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link NATTabel.Omschrijving }{@code >}
     *     
     */
    public void setOmschrijving(JAXBElement<NATTabel.Omschrijving> value) {
        this.omschrijving = value;
    }

    /**
     * Gets the value of the datumVerkrijging property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public JAXBElement<DatumMetIndicatorKerngegeven> getDatumVerkrijging() {
        return datumVerkrijging;
    }

    /**
     * Sets the value of the datumVerkrijging property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public void setDatumVerkrijging(JAXBElement<DatumMetIndicatorKerngegeven> value) {
        this.datumVerkrijging = value;
    }

    /**
     * Gets the value of the datumVerlies property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public JAXBElement<DatumMetIndicatorKerngegeven> getDatumVerlies() {
        return datumVerlies;
    }

    /**
     * Sets the value of the datumVerlies property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public void setDatumVerlies(JAXBElement<DatumMetIndicatorKerngegeven> value) {
        this.datumVerlies = value;
    }

    /**
     * Gets the value of the extraElementen property.
     * 
     * @return
     *     possible object is
     *     {@link ExtraElementen }
     *     
     */
    public ExtraElementen getExtraElementen() {
        return extraElementen;
    }

    /**
     * Sets the value of the extraElementen property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtraElementen }
     *     
     */
    public void setExtraElementen(ExtraElementen value) {
        this.extraElementen = value;
    }

    /**
     * Gets the value of the soortEntiteit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoortEntiteit() {
        if (soortEntiteit == null) {
            return "T";
        } else {
            return soortEntiteit;
        }
    }

    /**
     * Sets the value of the soortEntiteit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoortEntiteit(String value) {
        this.soortEntiteit = value;
    }

    /**
     * Gets the value of the verwerkingssoort property.
     * 
     * @return
     *     possible object is
     *     {@link Verwerkingssoort }
     *     
     */
    public Verwerkingssoort getVerwerkingssoort() {
        return verwerkingssoort;
    }

    /**
     * Sets the value of the verwerkingssoort property.
     * 
     * @param value
     *     allowed object is
     *     {@link Verwerkingssoort }
     *     
     */
    public void setVerwerkingssoort(Verwerkingssoort value) {
        this.verwerkingssoort = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;simpleContent>
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>Nationaliteitscode">
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
     *     &lt;/extension>
     *   &lt;/simpleContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class Code {

        @XmlValue
        protected BigInteger value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link BigInteger }
         *     
         */
        public BigInteger getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link BigInteger }
         *     
         */
        public void setValue(BigInteger value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;simpleContent>
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204>NationaliteitOmschrijving">
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/>
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" />
     *     &lt;/extension>
     *   &lt;/simpleContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class Omschrijving {

        @XmlValue
        protected String value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setValue(String value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }

}

==> brmo-stufbg204-2.0.0-sources.jar: nl/egem/stuf/sector/bg/_0204/NATTabel.java <==

package nl.egem.stuf.sector.bg._0204;

import java.math.BigInteger;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.XmlValue;
import nl.egem.stuf.stuf0204.DatumMetIndicatorKerngegeven;
import nl.egem.stuf.stuf0204.ExtraElementen;
import nl.egem.stuf.stuf0204.NoValue;
import nl.egem.stuf.stuf0204.Verwerkingssoort;


/**
 * tabel entiteit nationaliteit
 * 
 * <p>Java class for NAT-tabel complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NAT-tabel"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="code" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;Nationaliteitscode"&gt;
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="omschrijving" minOccurs="0"&gt;
 *           &lt;complexType&gt;
 *             &lt;simpleContent&gt;
 *               &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;NationaliteitOmschrijving"&gt;
 *                 &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
 *                 &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
 *               &lt;/extension&gt;
 *             &lt;/simpleContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="datumVerkrijging" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicatorKerngegeven" minOccurs="0"/&gt;
 *         &lt;element name="datumVerlies" type="{http://www.egem.nl/StUF/StUF0204}DatumMetIndicatorKerngegeven" minOccurs="0"/&gt;
 *         &lt;element name="extraElementen" type="{http://www.egem.nl/StUF/StUF0204}ExtraElementen" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}tabel"/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NAT-tabel", propOrder = {
    "code",
    "omschrijving",
    "datumVerkrijging",
    "datumVerlies",
    "extraElementen"
})
public class NATTabel {

    @XmlElementRef(name = "code", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<NATTabel.Code> code;
    @XmlElementRef(name = "omschrijving", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<NATTabel.Omschrijving> omschrijving;
    @XmlElementRef(name = "datumVerkrijging", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<DatumMetIndicatorKerngegeven> datumVerkrijging;
    @XmlElementRef(name = "datumVerlies", namespace = "http://www.egem.nl/StUF/sector/bg/0204", type = JAXBElement.class, required = false)
    protected JAXBElement<DatumMetIndicatorKerngegeven> datumVerlies;
    protected ExtraElementen extraElementen;
    @XmlAttribute(name = "soortEntiteit", required = true)
    protected String soortEntiteit;
    @XmlAttribute(name = "verwerkingssoort", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected Verwerkingssoort verwerkingssoort;
    @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
    protected NoValue noValue;

    /**
     * Gets the value of the code property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link NATTabel.Code }{@code >}
     *     
     */
    public JAXBElement<NATTabel.Code> getCode() {
        return code;
    }

    /**
     * Sets the value of the code property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link NATTabel.Code }{@code >}
     *     
     */
    public void setCode(JAXBElement<NATTabel.Code> value) {
        this.code = value;
    }

    /**
     * Gets the value of the omschrijving property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link NATTabel.Omschrijving }{@code >}
     *     
     */
    public JAXBElement<NATTabel.Omschrijving> getOmschrijving() {
        return omschrijving;
    }

    /**
     * Sets the value of the omschrijving property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link NATTabel.Omschrijving }{@code >}
     *     
     */
    public void setOmschrijving(JAXBElement<NATTabel.Omschrijving> value) {
        this.omschrijving = value;
    }

    /**
     * Gets the value of the datumVerkrijging property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public JAXBElement<DatumMetIndicatorKerngegeven> getDatumVerkrijging() {
        return datumVerkrijging;
    }

    /**
     * Sets the value of the datumVerkrijging property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public void setDatumVerkrijging(JAXBElement<DatumMetIndicatorKerngegeven> value) {
        this.datumVerkrijging = value;
    }

    /**
     * Gets the value of the datumVerlies property.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public JAXBElement<DatumMetIndicatorKerngegeven> getDatumVerlies() {
        return datumVerlies;
    }

    /**
     * Sets the value of the datumVerlies property.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link DatumMetIndicatorKerngegeven }{@code >}
     *     
     */
    public void setDatumVerlies(JAXBElement<DatumMetIndicatorKerngegeven> value) {
        this.datumVerlies = value;
    }

    /**
     * Gets the value of the extraElementen property.
     * 
     * @return
     *     possible object is
     *     {@link ExtraElementen }
     *     
     */
    public ExtraElementen getExtraElementen() {
        return extraElementen;
    }

    /**
     * Sets the value of the extraElementen property.
     * 
     * @param value
     *     allowed object is
     *     {@link ExtraElementen }
     *     
     */
    public void setExtraElementen(ExtraElementen value) {
        this.extraElementen = value;
    }

    /**
     * Gets the value of the soortEntiteit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoortEntiteit() {
        if (soortEntiteit == null) {
            return "T";
        } else {
            return soortEntiteit;
        }
    }

    /**
     * Sets the value of the soortEntiteit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoortEntiteit(String value) {
        this.soortEntiteit = value;
    }

    /**
     * Gets the value of the verwerkingssoort property.
     * 
     * @return
     *     possible object is
     *     {@link Verwerkingssoort }
     *     
     */
    public Verwerkingssoort getVerwerkingssoort() {
        return verwerkingssoort;
    }

    /**
     * Sets the value of the verwerkingssoort property.
     * 
     * @param value
     *     allowed object is
     *     {@link Verwerkingssoort }
     *     
     */
    public void setVerwerkingssoort(Verwerkingssoort value) {
        this.verwerkingssoort = value;
    }

    /**
     * Gets the value of the noValue property.
     * 
     * @return
     *     possible object is
     *     {@link NoValue }
     *     
     */
    public NoValue getNoValue() {
        return noValue;
    }

    /**
     * Sets the value of the noValue property.
     * 
     * @param value
     *     allowed object is
     *     {@link NoValue }
     *     
     */
    public void setNoValue(NoValue value) {
        this.noValue = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;Nationaliteitscode"&gt;
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class Code {

        @XmlValue
        protected BigInteger value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link BigInteger }
         *     
         */
        public BigInteger getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link BigInteger }
         *     
         */
        public void setValue(BigInteger value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;simpleContent&gt;
     *     &lt;extension base="&lt;http://www.egem.nl/StUF/sector/bg/0204&gt;NationaliteitOmschrijving"&gt;
     *       &lt;attGroup ref="{http://www.egem.nl/StUF/StUF0204}element"/&gt;
     *       &lt;attribute name="kerngegeven" type="{http://www.w3.org/2001/XMLSchema}boolean" fixed="true" /&gt;
     *     &lt;/extension&gt;
     *   &lt;/simpleContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "value"
    })
    public static class Omschrijving {

        @XmlValue
        protected String value;
        @XmlAttribute(name = "kerngegeven")
        protected Boolean kerngegeven;
        @XmlAttribute(name = "noValue", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected NoValue noValue;
        @XmlAttribute(name = "exact", namespace = "http://www.egem.nl/StUF/StUF0204")
        protected Boolean exact;

        /**
         * Gets the value of the value property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getValue() {
            return value;
        }

        /**
         * Sets the value of the value property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setValue(String value) {
            this.value = value;
        }

        /**
         * Gets the value of the kerngegeven property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isKerngegeven() {
            if (kerngegeven == null) {
                return true;
            } else {
                return kerngegeven;
            }
        }

        /**
         * Sets the value of the kerngegeven property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setKerngegeven(Boolean value) {
            this.kerngegeven = value;
        }

        /**
         * Gets the value of the noValue property.
         * 
         * @return
         *     possible object is
         *     {@link NoValue }
         *     
         */
        public NoValue getNoValue() {
            return noValue;
        }

        /**
         * Sets the value of the noValue property.
         * 
         * @param value
         *     allowed object is
         *     {@link NoValue }
         *     
         */
        public void setNoValue(NoValue value) {
            this.noValue = value;
        }

        /**
         * Gets the value of the exact property.
         * 
         * @return
         *     possible object is
         *     {@link Boolean }
         *     
         */
        public boolean isExact() {
            if (exact == null) {
                return true;
            } else {
                return exact;
            }
        }

        /**
         * Sets the value of the exact property.
         * 
         * @param value
         *     allowed object is
         *     {@link Boolean }
         *     
         */
        public void setExact(Boolean value) {
            this.exact = value;
        }

    }

}
